==> hindent-5.2.7-20-armv7h.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-KaOT633ECClBtR5opxCODR
key: hindent-5.2.7-KaOT633ECClBtR5opxCODR
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 8b1693f32ef41ea16656a423d1d29a6b
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-KaOT633ECClBtR5opxCODR
depends:
    base-4.11.1.0 containers-0.5.11.0 Cabal-2.2.0.1 filepath-1.4.2
    directory-1.3.1.5 haskell-src-exts-1.20.2-IzOj38b1Ox84zk53jWdw9J
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs mtl-2.2.2
    bytestring-0.10.8.2 utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    transformers-0.5.5.0 exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    text-1.2.3.0 yaml-0.10.1.1-LrwE35r3aJnKEIe4Y6Xrum
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             haskell-src-exts-1.20.2-IzOj38b1Ox84zk53jWdw9J=1ff0290fb9631c69b5b2dd35ff9ca710
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=169ceee9ae683d41008e7f14821d1ce1
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             yaml-0.10.1.1-LrwE35r3aJnKEIe4Y6Xrum=966475a2b215357f7cde8af5e854b9fa
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.7-22-armv7h.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-GU3N3U3XvCU2HCagW6PQtT
key: hindent-5.2.7-GU3N3U3XvCU2HCagW6PQtT
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: c89668acf9c30863f3c0bff20aa18ca3
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-GU3N3U3XvCU2HCagW6PQtT
depends:
    base-4.11.1.0 containers-0.5.11.0 Cabal-2.2.0.1 filepath-1.4.2
    directory-1.3.1.5 haskell-src-exts-1.20.2-JbnQInDwQEnBK1L9b3hAb8
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs mtl-2.2.2
    bytestring-0.10.8.2 utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    transformers-0.5.5.0 exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc
    text-1.2.3.0 yaml-0.10.1.1-69Hlp1ysidOFKgN68pnzUk
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             haskell-src-exts-1.20.2-JbnQInDwQEnBK1L9b3hAb8=efc2b93364e656ecec4b2f0ba6e3725f
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=169ceee9ae683d41008e7f14821d1ce1
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc=7e2a2010d6645bddac83e90b3cee8839
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             yaml-0.10.1.1-69Hlp1ysidOFKgN68pnzUk=47712b9fe3a559ee682a0d8de7fb5aab
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
